package Bundle::Locale::CLDR::Southernasia;

use version;

our $VERSION = version->declare('v0.34.1');

=head1 NAME Bundle::Locale::CLDR::Southernasia

=head1 CONTENTS

Locale::CLDR::Locales::As 0.34.1
Locale::CLDR::Locales::Bn 0.34.1
Locale::CLDR::Locales::Bo 0.34.1
Locale::CLDR::Locales::Dz 0.34.1
Locale::CLDR::Locales::Fa 0.34.1
Locale::CLDR::Locales::Gu 0.34.1
Locale::CLDR::Locales::Hi 0.34.1
Locale::CLDR::Locales::Kn 0.34.1
Locale::CLDR::Locales::Ks 0.34.1
Locale::CLDR::Locales::Ml 0.34.1
Locale::CLDR::Locales::Mr 0.34.1
Locale::CLDR::Locales::Ne 0.34.1
Locale::CLDR::Locales::Or 0.34.1
Locale::CLDR::Locales::Pa 0.34.1
Locale::CLDR::Locales::Ps 0.34.1
Locale::CLDR::Locales::Sd 0.34.1
Locale::CLDR::Locales::Si 0.34.1
Locale::CLDR::Locales::Ta 0.34.1
Locale::CLDR::Locales::Te 0.34.1
Locale::CLDR::Locales::Ur 0.34.1
Locale::CLDR::Locales::Uz 0.34.1
Locale::CLDR::Locales::Brx 0.34.1
Locale::CLDR::Locales::Ccp 0.34.1
Locale::CLDR::Locales::Ckb 0.34.1
Locale::CLDR::Locales::Kok 0.34.1
Locale::CLDR::Locales::Lrc 0.34.1
Locale::CLDR::Locales::Mzn 0.34.1
Locale::CLDR::Locales::As::Any 0.34.1
Locale::CLDR::Locales::Bn::Any 0.34.1
Locale::CLDR::Locales::Bo::Any 0.34.1
Locale::CLDR::Locales::Dz::Any 0.34.1
Locale::CLDR::Locales::En::Any 0.34.1
Locale::CLDR::Locales::Fa::Any 0.34.1
Locale::CLDR::Locales::Gu::Any 0.34.1
Locale::CLDR::Locales::Hi::Any 0.34.1
Locale::CLDR::Locales::Kn::Any 0.34.1
Locale::CLDR::Locales::Ks::Any 0.34.1
Locale::CLDR::Locales::Ml::Any 0.34.1
Locale::CLDR::Locales::Mr::Any 0.34.1
Locale::CLDR::Locales::Ne::Any 0.34.1
Locale::CLDR::Locales::Or::Any 0.34.1
Locale::CLDR::Locales::Ps::Any 0.34.1
Locale::CLDR::Locales::Sd::Any 0.34.1
Locale::CLDR::Locales::Si::Any 0.34.1
Locale::CLDR::Locales::Ta::Any 0.34.1
Locale::CLDR::Locales::Te::Any 0.34.1
Locale::CLDR::Locales::Ur::Any 0.34.1
Locale::CLDR::Locales::Brx::Any 0.34.1
Locale::CLDR::Locales::Ccp::Any 0.34.1
Locale::CLDR::Locales::Ckb::Any 0.34.1
Locale::CLDR::Locales::Kok::Any 0.34.1
Locale::CLDR::Locales::Lrc::Any 0.34.1
Locale::CLDR::Locales::Mzn::Any 0.34.1
Locale::CLDR::Locales::Pa::Arab 0.34.1
Locale::CLDR::Locales::Pa::Guru 0.34.1
Locale::CLDR::Locales::Uz::Arab 0.34.1
Locale::CLDR::Locales::As::Any::In 0.34.1
Locale::CLDR::Locales::Bn::Any::Bd 0.34.1
Locale::CLDR::Locales::Bn::Any::In 0.34.1
Locale::CLDR::Locales::Bo::Any::In 0.34.1
Locale::CLDR::Locales::Dz::Any::Bt 0.34.1
Locale::CLDR::Locales::En::Any::In 0.34.1
Locale::CLDR::Locales::En::Any::Pk 0.34.1
Locale::CLDR::Locales::Fa::Any::Af 0.34.1
Locale::CLDR::Locales::Fa::Any::Ir 0.34.1
Locale::CLDR::Locales::Gu::Any::In 0.34.1
Locale::CLDR::Locales::Hi::Any::In 0.34.1
Locale::CLDR::Locales::Kn::Any::In 0.34.1
Locale::CLDR::Locales::Ks::Any::In 0.34.1
Locale::CLDR::Locales::Ml::Any::In 0.34.1
Locale::CLDR::Locales::Mr::Any::In 0.34.1
Locale::CLDR::Locales::Ne::Any::In 0.34.1
Locale::CLDR::Locales::Ne::Any::Np 0.34.1
Locale::CLDR::Locales::Or::Any::In 0.34.1
Locale::CLDR::Locales::Ps::Any::Af 0.34.1
Locale::CLDR::Locales::Sd::Any::Pk 0.34.1
Locale::CLDR::Locales::Si::Any::Lk 0.34.1
Locale::CLDR::Locales::Ta::Any::In 0.34.1
Locale::CLDR::Locales::Ta::Any::Lk 0.34.1
Locale::CLDR::Locales::Te::Any::In 0.34.1
Locale::CLDR::Locales::Ur::Any::In 0.34.1
Locale::CLDR::Locales::Ur::Any::Pk 0.34.1
Locale::CLDR::Locales::Brx::Any::In 0.34.1
Locale::CLDR::Locales::Ccp::Any::Bd 0.34.1
Locale::CLDR::Locales::Ccp::Any::In 0.34.1
Locale::CLDR::Locales::Ckb::Any::Ir 0.34.1
Locale::CLDR::Locales::En::Any::001 0.34.1
Locale::CLDR::Locales::Kok::Any::In 0.34.1
Locale::CLDR::Locales::Lrc::Any::Ir 0.34.1
Locale::CLDR::Locales::Mzn::Any::Ir 0.34.1
Locale::CLDR::Locales::Pa::Arab::Pk 0.34.1
Locale::CLDR::Locales::Pa::Guru::In 0.34.1
Locale::CLDR::Locales::Uz::Arab::Af 0.34.1

=cut

1;

